package com.yunzhi.questions.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.questions.common.BaseController;
import com.yunzhi.questions.common.Constants;
import com.yunzhi.questions.common.ResponseBean;
import com.yunzhi.questions.entity.SysUser;
import com.yunzhi.questions.entity.TdCharacterWord;
import com.yunzhi.questions.service.ITdCharacterLibService;
import com.yunzhi.questions.service.ITdCharacterWordService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import com.yunzhi.questions.service.ITaCharacterResultService;
import com.yunzhi.questions.entity.TaCharacterResult;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletRequest;
import java.util.List;

/**
 * <p>
    * 游戏特征实例 前端控制器
    * </p>
 *
 * @author yansen
 * @since 2021-12-15
 */

@Api(tags = "游戏特征实例")
@RestController
@RequestMapping("/")
public class TaCharacterResultController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaCharacterResultController.class);

    @Autowired
    public ITaCharacterResultService iTaCharacterResultService;

    @Autowired
    public ITdCharacterLibService iTdCharacterLibService;

    @Autowired
    public ITdCharacterWordService iTdCharacterWordService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/admin/character-result",method= RequestMethod.GET)
    @ApiOperation(value="游戏特征实例列表", notes = "游戏特征实例列表", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean taCharacterResultList(@ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                              @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize) throws Exception{

		    IPage<TaCharacterResult> pg = new Page<>(pageNum, pageSize);
            QueryWrapper<TaCharacterResult> queryWrapper = new QueryWrapper<>();
            queryWrapper.orderByDesc("create_date");

            IPage<TaCharacterResult> result = iTaCharacterResultService.page(pg, queryWrapper);
            return ResponseBean.success(result);
    }

    /**
     * 保存对象
     * @param taCharacterResult 实体对象
     * @return
     */
    @RequestMapping(value="/admin/character-result",method= RequestMethod.POST)
    @ApiOperation(value="保存", notes = "保存", httpMethod = "POST", response = ResponseBean.class)
    public ResponseBean taCharacterResultAdd(@ApiParam("保存内容") @RequestBody TaCharacterResult taCharacterResult,
                                             HttpServletRequest request) throws Exception{
        SysUser user = getCurrentUser(request);
        int rows = iTdCharacterLibService.getCountOfMapUser(user.getUserId(), taCharacterResult.getLibId());
        if (rows < 1) {
            return ResponseBean.error("没有找到所属特征库, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }

        if (iTaCharacterResultService.saveWithWords(user, taCharacterResult)){
            return ResponseBean.success(taCharacterResult);
        }else {
            return ResponseBean.error("保存失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @RequestMapping(value="/taCharacterResult/{id}", method= RequestMethod.DELETE)
    @ApiOperation(value="删除", notes = "删除", httpMethod = "DELETE", response = ResponseBean.class)
    public ResponseBean taCharacterResultDelete(@ApiParam("对象ID") @PathVariable String id,
                                                HttpServletRequest request) throws Exception{

        TaCharacterResult taCharacterResult = iTaCharacterResultService.getById(id);
        if (null == taCharacterResult || taCharacterResult.getStatus() == Constants.STATUS_DELETED) {
            return ResponseBean.error("没有找到所属特征库, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }

        int rows = iTdCharacterLibService.getCountOfMapUser(getCurrentUser(request).getUserId(), taCharacterResult.getLibId());
        if (rows < 1) {
            return ResponseBean.error("没有找到所属特征库, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }

        if(iTaCharacterResultService.removeLogicById(id)){
            return ResponseBean.success("success");
        }else {
            return ResponseBean.error("删除失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param taCharacterResult 实体对象
     * @return
     */
    @RequestMapping(value="/taCharacterResult/{id}",method= RequestMethod.PUT)
    @ApiOperation(value="更新", notes = "更新", httpMethod = "PUT", response = ResponseBean.class)
    public ResponseBean taCharacterResultUpdate(@ApiParam("对象ID") @PathVariable String id,
                                                @ApiParam("更新内容") @RequestBody TaCharacterResult taCharacterResult,
                                                HttpServletRequest request) throws Exception{
        TaCharacterResult origin = iTaCharacterResultService.getById(id);
        if (null == origin || origin.getStatus() == Constants.STATUS_DELETED) {
            return ResponseBean.error("没有找到所属特征库, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }

        int rows = iTdCharacterLibService.getCountOfMapUser(getCurrentUser(request).getUserId(), origin.getLibId());
        if (rows < 1) {
            return ResponseBean.error("没有找到所属特征库, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }

        taCharacterResult.setResultId(id);
        taCharacterResult.setLibId(origin.getLibId());

        if (iTaCharacterResultService.updateWithWords(taCharacterResult)){
            return ResponseBean.success(iTaCharacterResultService.getById(id));
        }else {
            return ResponseBean.error("修改失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/taCharacterResult/{id}",method= RequestMethod.GET)
    @ApiOperation(value="详情", notes = "详情", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean taCharacterResultGet(@ApiParam("对象ID") @PathVariable String id,
                                             HttpServletRequest request) throws Exception{
        TaCharacterResult taCharacterResult = iTaCharacterResultService.getById(id);
        if (null == taCharacterResult || taCharacterResult.getStatus() == Constants.STATUS_DELETED) {
            return ResponseBean.error("没有找到所属特征库, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }

        int rows = iTdCharacterLibService.getCountOfMapUser(getCurrentUser(request).getUserId(), taCharacterResult.getLibId());
        if (rows < 1) {
            return ResponseBean.error("没有找到所属特征库, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }

        List<TdCharacterWord> wordList = iTdCharacterWordService.getListByResultId(id);
        taCharacterResult.setWordList(wordList);

        return ResponseBean.success(taCharacterResult);
    }
}
