package com.yunzhi.questions.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.questions.common.BaseController;
import com.yunzhi.questions.common.Constants;
import com.yunzhi.questions.common.ResponseBean;
import com.yunzhi.questions.common.StringUtils;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import com.yunzhi.questions.service.ITaGameLevelService;
import com.yunzhi.questions.entity.TaGameLevel;
import org.springframework.web.bind.annotation.RestController;

/**
 * <p>
    * 关卡 前端控制器
    * </p>
 *
 * @author yansen
 * @since 2021-12-10
 */

@Api(tags = "关卡")
@RestController
@RequestMapping("/")
public class TaGameLevelController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaGameLevelController.class);

    @Autowired
    public ITaGameLevelService iTaGameLevelService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/admin/game-level",method= RequestMethod.GET)
    @ApiOperation(value="列表", notes = "列表", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean taGameLevelList(@ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                        @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize) throws Exception{

		    IPage<TaGameLevel> pg = new Page<>(pageNum, pageSize);
            QueryWrapper<TaGameLevel> queryWrapper = new QueryWrapper<>();
            queryWrapper.orderByDesc("create_date");

            IPage<TaGameLevel> result = iTaGameLevelService.page(pg, queryWrapper);
            return ResponseBean.success(result);
    }

    /**
     * 保存对象
     * @param taGameLevel 实体对象
     * @return
     */
    @RequestMapping(value="/admin/game-level",method= RequestMethod.POST)
    @ApiOperation(value="保存", notes = "保存", httpMethod = "POST", response = ResponseBean.class)
    public ResponseBean taGameLevelAdd(@ApiParam("保存内容") @RequestBody TaGameLevel taGameLevel) throws Exception{

        if (StringUtils.isEmpty(taGameLevel.getGameId())) {
            return ResponseBean.error("未找到相关联的游戏内容", ResponseBean.ERROR_UNAVAILABLE);
        }

        taGameLevel.setLevelId(null);
        if (null == taGameLevel.getStatus()) {
            taGameLevel.setStatus(Constants.STATUS_READY);
        }

        if (iTaGameLevelService.save(taGameLevel)){
            return ResponseBean.success(taGameLevel);
        }else {
            return ResponseBean.error("保存失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @RequestMapping(value="/admin/game-level/{id}", method= RequestMethod.DELETE)
    @ApiOperation(value="删除", notes = "删除", httpMethod = "DELETE", response = ResponseBean.class)
    public ResponseBean taGameLevelDelete(@ApiParam("对象ID") @PathVariable String id) throws Exception{
        if(iTaGameLevelService.removeLogicById(id)){
            return ResponseBean.success("success");
        }else {
            return ResponseBean.error("删除失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param taGameLevel 实体对象
     * @return
     */
    @RequestMapping(value="/admin/game-level/{id}",method= RequestMethod.PUT)
    @ApiOperation(value="更新", notes = "更新", httpMethod = "PUT", response = ResponseBean.class)
    public ResponseBean taGameLevelUpdate(@ApiParam("对象ID") @PathVariable String id,
                                          @ApiParam("更新内容") @RequestBody TaGameLevel taGameLevel) throws Exception{
        if (StringUtils.isEmpty(taGameLevel.getGameId())) {
            return ResponseBean.error("未找到相关联的游戏内容", ResponseBean.ERROR_UNAVAILABLE);
        }

        if (iTaGameLevelService.updateById(taGameLevel)){
            return ResponseBean.success(iTaGameLevelService.getById(id));
        }else {
            return ResponseBean.error("修改失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/admin/game-level/{id}",method= RequestMethod.GET)
    @ApiOperation(value="详情", notes = "详情", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean taGameLevelGet(@ApiParam("对象ID") @PathVariable String id) throws Exception{
        return ResponseBean.success(iTaGameLevelService.getById(id));
    }
}
