package com.yunzhi.questions.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.questions.common.BaseController;
import com.yunzhi.questions.common.ResponseBean;
import com.yunzhi.questions.common.StringUtils;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import com.yunzhi.questions.service.ITaGameLevelQuestionService;
import com.yunzhi.questions.entity.TaGameLevelQuestion;
import org.springframework.web.bind.annotation.RestController;

/**
 * <p>
    * 关卡问题 前端控制器
    * </p>
 *
 * @author yansen
 * @since 2021-12-10
 */

@Api(tags = "关卡问题")
@RestController
@RequestMapping("/")
public class TaGameLevelQuestionController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaGameLevelQuestionController.class);

    @Autowired
    public ITaGameLevelQuestionService iTaGameLevelQuestionService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/admin/game-level-question",method= RequestMethod.GET)
    @ApiOperation(value="列表", notes = "列表", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean taGameLevelQuestionList(@ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                                @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize) throws Exception{

		    IPage<TaGameLevelQuestion> pg = new Page<>(pageNum, pageSize);
            QueryWrapper<TaGameLevelQuestion> queryWrapper = new QueryWrapper<>();
            queryWrapper.orderByDesc("create_date");

            IPage<TaGameLevelQuestion> result = iTaGameLevelQuestionService.page(pg, queryWrapper);
            return ResponseBean.success(result);
    }

    /**
     * 保存关卡游戏内容
     * @param taGameLevelQuestion 实体对象
     * @return
     */
    @RequestMapping(value="/admin/game-level-question",method= RequestMethod.POST)
    @ApiOperation(value="保存关卡游戏内容", notes = "保存关卡游戏内容", httpMethod = "POST", response = ResponseBean.class)
    public ResponseBean taGameLevelQuestionAdd(@ApiParam("保存内容") @RequestBody TaGameLevelQuestion taGameLevelQuestion) throws Exception{

        if (StringUtils.isEmpty(taGameLevelQuestion.getQuestionId()) || StringUtils.isEmpty(taGameLevelQuestion.getLevelId())) {
            return ResponseBean.error("未找到对应关卡或者问题相关内容", ResponseBean.ERROR_UNAVAILABLE);
        }

        if (iTaGameLevelQuestionService.save(taGameLevelQuestion)){
            return ResponseBean.success(taGameLevelQuestion);
        }else {
            return ResponseBean.error("保存失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @RequestMapping(value="/admin/game-level-question/{id}", method= RequestMethod.DELETE)
    @ApiOperation(value="删除", notes = "删除", httpMethod = "DELETE", response = ResponseBean.class)
    public ResponseBean taGameLevelQuestionDelete(@ApiParam("对象ID") @PathVariable Integer id) throws Exception{
        if(iTaGameLevelQuestionService.removeById(id)){
            return ResponseBean.success("success");
        }else {
            return ResponseBean.error("删除失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param taGameLevelQuestion 实体对象
     * @return
     */
    @RequestMapping(value="/admin/game-level-question/{id}",method= RequestMethod.PUT)
    @ApiOperation(value="更新", notes = "更新", httpMethod = "PUT", response = ResponseBean.class)
    public ResponseBean taGameLevelQuestionUpdate(@ApiParam("对象ID") @PathVariable Integer id,
                                                  @ApiParam("更新内容") @RequestBody TaGameLevelQuestion taGameLevelQuestion) throws Exception{

        if (StringUtils.isEmpty(taGameLevelQuestion.getQuestionId()) || StringUtils.isEmpty(taGameLevelQuestion.getLevelId())) {
            return ResponseBean.error("未找到对应关卡或者问题相关内容", ResponseBean.ERROR_UNAVAILABLE);
        }

        taGameLevelQuestion.setSerialNo(id);

        if (iTaGameLevelQuestionService.updateById(taGameLevelQuestion)){
            return ResponseBean.success(iTaGameLevelQuestionService.getById(id));
        }else {
            return ResponseBean.error("修改失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/admin/game-level-question/{id}",method= RequestMethod.GET)
    @ApiOperation(value="详情", notes = "详情", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean taGameLevelQuestionGet(@ApiParam("对象ID") @PathVariable Integer id) throws Exception{
        return ResponseBean.success(iTaGameLevelQuestionService.getById(id));
    }
}
