package com.yunzhi.questions.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.questions.common.BaseController;
import com.yunzhi.questions.common.ResponseBean;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import com.yunzhi.questions.service.ITaGamePersonService;
import com.yunzhi.questions.entity.TaGamePerson;
import org.springframework.web.bind.annotation.RestController;

/**
 * <p>
    * 参与游戏人员 前端控制器
    * </p>
 *
 * @author yansen
 * @since 2021-12-10
 */

@Api(tags = "参与游戏人员")
@RestController
@RequestMapping("/")
public class TaGamePersonController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaGamePersonController.class);

    @Autowired
    public ITaGamePersonService iTaGamePersonService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/taGamePerson",method= RequestMethod.GET)
    @ApiOperation(value="列表", notes = "列表", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean taGamePersonList(@ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
									 @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize) throws Exception{

		    IPage<TaGamePerson> pg = new Page<>(pageNum, pageSize);
            QueryWrapper<TaGamePerson> queryWrapper = new QueryWrapper<>();
            queryWrapper.orderByDesc("create_date");

            IPage<TaGamePerson> result = iTaGamePersonService.page(pg, queryWrapper);
            return ResponseBean.success(result);
    }

    /**
     * 保存对象
     * @param taGamePerson 实体对象
     * @return
     */
    @RequestMapping(value="/taGamePerson",method= RequestMethod.POST)
    @ApiOperation(value="保存", notes = "保存", httpMethod = "POST", response = ResponseBean.class)
    public ResponseBean taGamePersonAdd(@ApiParam("保存内容") @RequestBody TaGamePerson taGamePerson) throws Exception{

        if (iTaGamePersonService.save(taGamePerson)){
            return ResponseBean.success(taGamePerson);
        }else {
            return ResponseBean.error("保存失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @RequestMapping(value="/taGamePerson/{id}", method= RequestMethod.DELETE)
    @ApiOperation(value="删除", notes = "删除", httpMethod = "DELETE", response = ResponseBean.class)
    public ResponseBean taGamePersonDelete(@ApiParam("对象ID") @PathVariable Integer id) throws Exception{
        if(iTaGamePersonService.removeById(id)){
            return ResponseBean.success("success");
        }else {
            return ResponseBean.error("删除失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param taGamePerson 实体对象
     * @return
     */
    @RequestMapping(value="/taGamePerson/{id}",method= RequestMethod.PUT)
    @ApiOperation(value="更新", notes = "更新", httpMethod = "PUT", response = ResponseBean.class)
    public ResponseBean taGamePersonUpdate(@ApiParam("对象ID") @PathVariable Integer id,
                                        @ApiParam("更新内容") @RequestBody TaGamePerson taGamePerson) throws Exception{

        if (iTaGamePersonService.updateById(taGamePerson)){
            return ResponseBean.success(iTaGamePersonService.getById(id));
        }else {
            return ResponseBean.error("修改失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/taGamePerson/{id}",method= RequestMethod.GET)
    @ApiOperation(value="详情", notes = "详情", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean taGamePersonGet(@ApiParam("对象ID") @PathVariable Integer id) throws Exception{
        return ResponseBean.success(iTaGamePersonService.getById(id));
    }
}
