package com.yunzhi.questions.controller;

import com.yunzhi.questions.common.BaseController;
import com.yunzhi.questions.common.ResponseBean;
import com.yunzhi.questions.common.StringUtils;
import com.yunzhi.questions.entity.TaGamePersonAnswer;
import com.yunzhi.questions.entity.TaPerson;
import com.yunzhi.questions.service.ITaAnswerService;
import com.yunzhi.questions.service.ITaGameService;
import com.yunzhi.questions.service.ITaQuestionService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import com.yunzhi.questions.service.ITaGamePersonResultService;
import com.yunzhi.questions.entity.TaGamePersonResult;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletRequest;
import java.util.List;

/**
 * <p>
    * 问答游戏总结 前端控制器
    * </p>
 *
 * @author yansen
 * @since 2021-12-15
 */

@Api(tags = "问答游戏总结")
@RestController
@RequestMapping("/")
public class TaGamePersonResultController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaGamePersonResultController.class);

    @Autowired
    public ITaGamePersonResultService iTaGamePersonResultService;

    @Autowired
    public ITaAnswerService iTaAnswerService;

    @Autowired
    public ITaQuestionService iTaQuestionService;


//    /**
//     * 分页查询列表
//     * @param pageNum
//     * @param pageSize
//     * @return
//     */
//    @RequestMapping(value="/taGamePersonResult",method= RequestMethod.GET)
//    @ApiOperation(value="列表", notes = "列表", httpMethod = "GET", response = ResponseBean.class)
//    public ResponseBean taGamePersonResultList(@ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
//									 @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize) throws Exception{
//
//		    IPage<TaGamePersonResult> pg = new Page<>(pageNum, pageSize);
//            QueryWrapper<TaGamePersonResult> queryWrapper = new QueryWrapper<>();
//            queryWrapper.orderByDesc("create_date");
//
//            IPage<TaGamePersonResult> result = iTaGamePersonResultService.page(pg, queryWrapper);
//            return ResponseBean.success(result);
//    }

    /**
     * 保存对象
     * @param taGamePersonResult 实体对象
     * @return
     */
    @RequestMapping(value="/game-answer",method= RequestMethod.POST)
    @ApiOperation(value="保存", notes = "保存", httpMethod = "POST", response = ResponseBean.class)
    public ResponseBean taGamePersonResultAdd(@ApiParam("保存内容") @RequestBody TaGamePersonResult taGamePersonResult,
                                              HttpServletRequest request) throws Exception{
        TaPerson taPerson = getCurrentPerson(request);

        String gameId = taGamePersonResult.getGameId();
        if (StringUtils.isEmpty(gameId)) {
            return ResponseBean.error("请设置问卷ID", ResponseBean.ERROR_UNAVAILABLE);
        }

        List<TaGamePersonAnswer> answerList = taGamePersonResult.getAnswerList();
        if (null == answerList || answerList.size() < 1) {
            return ResponseBean.error("未找到答题信息", ResponseBean.ERROR_UNAVAILABLE);
        }

        int totalNum = iTaQuestionService.countByGameId(gameId);
        if (totalNum != answerList.size()) {
            return ResponseBean.error("尚有未作答的题目", ResponseBean.ERROR_UNAVAILABLE);
        }

        if (iTaGamePersonResultService.makeAnswer(taGamePersonResult)){
            return ResponseBean.success(taGamePersonResult);
        }else {
            return ResponseBean.error("保存失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @RequestMapping(value="/taGamePersonResult/{id}", method= RequestMethod.DELETE)
    @ApiOperation(value="删除", notes = "删除", httpMethod = "DELETE", response = ResponseBean.class)
    public ResponseBean taGamePersonResultDelete(@ApiParam("对象ID") @PathVariable Integer id) throws Exception{
        if(iTaGamePersonResultService.removeById(id)){
            return ResponseBean.success("success");
        }else {
            return ResponseBean.error("删除失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param taGamePersonResult 实体对象
     * @return
     */
    @RequestMapping(value="/taGamePersonResult/{id}",method= RequestMethod.PUT)
    @ApiOperation(value="更新", notes = "更新", httpMethod = "PUT", response = ResponseBean.class)
    public ResponseBean taGamePersonResultUpdate(@ApiParam("对象ID") @PathVariable Integer id,
                                        @ApiParam("更新内容") @RequestBody TaGamePersonResult taGamePersonResult) throws Exception{

        if (iTaGamePersonResultService.updateById(taGamePersonResult)){
            return ResponseBean.success(iTaGamePersonResultService.getById(id));
        }else {
            return ResponseBean.error("修改失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/taGamePersonResult/{id}",method= RequestMethod.GET)
    @ApiOperation(value="详情", notes = "详情", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean taGamePersonResultGet(@ApiParam("对象ID") @PathVariable Integer id) throws Exception{
        return ResponseBean.success(iTaGamePersonResultService.getById(id));
    }
}
