package com.yunzhi.questions.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.questions.common.BaseController;
import com.yunzhi.questions.common.Constants;
import com.yunzhi.questions.common.ResponseBean;
import com.yunzhi.questions.entity.TaAnswer;
import com.yunzhi.questions.service.ITaAnswerService;
import com.yunzhi.questions.vo.QuestionVO;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import com.yunzhi.questions.service.ITaQuestionService;
import com.yunzhi.questions.entity.TaQuestion;
import org.springframework.web.bind.annotation.RestController;

import java.time.LocalDateTime;
import java.util.List;

/**
 * <p>
    * 题库 前端控制器
    * </p>
 *
 * @author yansen
 * @since 2021-12-10
 */

@Api(tags = "题库")
@RestController
@RequestMapping("/")
public class TaQuestionController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaQuestionController.class);

    @Autowired
    public ITaQuestionService iTaQuestionService;

    @Autowired
    public ITaAnswerService iTaAnswerService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/admin/question",method= RequestMethod.GET)
    @ApiOperation(value="列表", notes = "列表", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean taQuestionList(@ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
									 @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize) throws Exception{

		    IPage<TaQuestion> pg = new Page<>(pageNum, pageSize);
            QueryWrapper<TaQuestion> queryWrapper = new QueryWrapper<>();
            queryWrapper.orderByDesc("create_date");

            IPage<TaQuestion> result = iTaQuestionService.page(pg, queryWrapper);
            return ResponseBean.success(result);
    }

    /**
     * 题库保存
     * @param questionVO 实体对象
     * @return
     */
    @RequestMapping(value="/admin/question",method= RequestMethod.POST)
    @ApiOperation(value="题库保存", notes = "题库保存", httpMethod = "POST", response = ResponseBean.class)
    public ResponseBean taQuestionAdd(@ApiParam("保存内容") @RequestBody QuestionVO questionVO) throws Exception{

        if (null == questionVO) {
            return ResponseBean.error("题库内容不能为空", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        if (null == questionVO.getAnswerList() || questionVO.getAnswerList().size() == 0) {
            return ResponseBean.error("题库答案列表不能为空", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        if (iTaQuestionService.saveByVO(questionVO)){
            return ResponseBean.success(questionVO);
        }else {
            return ResponseBean.error("保存失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @RequestMapping(value="/admin/question/{id}", method= RequestMethod.DELETE)
    @ApiOperation(value="删除", notes = "删除", httpMethod = "DELETE", response = ResponseBean.class)
    public ResponseBean taQuestionDelete(@ApiParam("对象ID") @PathVariable String id) throws Exception{
        if(iTaQuestionService.removeLogicById(id)){
            return ResponseBean.success("success");
        }else {
            return ResponseBean.error("删除失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 题库修改
     * @param id  实体ID
     * @param questionVO 实体对象
     * @return
     */
    @RequestMapping(value="/admin/question/{id}",method= RequestMethod.PUT)
    @ApiOperation(value="题库修改", notes = "题库修改", httpMethod = "PUT", response = ResponseBean.class)
    public ResponseBean taQuestionUpdate(@ApiParam("对象ID") @PathVariable String id,
                                         @ApiParam("更新内容") @RequestBody QuestionVO questionVO) throws Exception{

        TaQuestion taQuestion = iTaQuestionService.getById(id);
        if (null == taQuestion || taQuestion.getStatus() == Constants.STATUS_DELETED) {
            return ResponseBean.error("未找到有效的更新内容", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        questionVO.setQuestionId(id);

        if (iTaQuestionService.editBy(questionVO)){
            return ResponseBean.success(questionVO);
        }else {
            return ResponseBean.error("修改失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/admin/question/{id}",method= RequestMethod.GET)
    @ApiOperation(value="详情", notes = "详情", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean taQuestionGet(@ApiParam("对象ID") @PathVariable String id) throws Exception{

        TaQuestion taQuestion = iTaQuestionService.getById(id);
        if (null == taQuestion || taQuestion.getStatus() == Constants.STATUS_DELETED) {
            return ResponseBean.error("未找到题库内容", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        List<TaAnswer> answerList = iTaAnswerService.getByQuestionId(id);

        QuestionVO questionVO = new QuestionVO();
        BeanUtils.copyProperties(taQuestion, questionVO);

        questionVO.setAnswerList(answerList);

        return ResponseBean.success(questionVO);
    }
}
