package com.yunzhi.questions.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.questions.common.BaseController;
import com.yunzhi.questions.common.Constants;
import com.yunzhi.questions.common.ResponseBean;
import com.yunzhi.questions.entity.SysUser;
import com.yunzhi.questions.entity.TdCharacterWord;
import com.yunzhi.questions.service.ITdCharacterWordService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import com.yunzhi.questions.service.ITdCharacterLibService;
import com.yunzhi.questions.entity.TdCharacterLib;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletRequest;
import java.util.List;

/**
 * <p>
    * 特征库 前端控制器
    * </p>
 *
 * @author yansen
 * @since 2021-12-14
 */

@Api(tags = "特征库")
@RestController
@RequestMapping("/")
public class TdCharacterLibController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TdCharacterLibController.class);

    @Autowired
    public ITdCharacterLibService iTdCharacterLibService;

    @Autowired
    public ITdCharacterWordService iTdCharacterWordService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/admin/character-lib",method= RequestMethod.GET)
    @ApiOperation(value="列表", notes = "列表", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean tdCharacterLibList(@ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
									 @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize) throws Exception{

		    IPage<TdCharacterLib> pg = new Page<>(pageNum, pageSize);
            QueryWrapper<TdCharacterLib> queryWrapper = new QueryWrapper<>();
            queryWrapper.orderByDesc("create_date");

            IPage<TdCharacterLib> result = iTdCharacterLibService.page(pg, queryWrapper);
            return ResponseBean.success(result);
    }

    /**
     * 保存特征库
     * @param tdCharacterLib 实体对象
     * @return
     */
    @RequestMapping(value="/admin/character-lib",method= RequestMethod.POST)
    @ApiOperation(value="保存特征库", notes = "保存特征库", httpMethod = "POST", response = ResponseBean.class)
    public ResponseBean tdCharacterLibAdd(@ApiParam("保存内容") @RequestBody TdCharacterLib tdCharacterLib,
                                          HttpServletRequest request) throws Exception{

        SysUser user = getCurrentUser(request);

        if (iTdCharacterLibService.saveWithList(user, tdCharacterLib)){
            return ResponseBean.success(tdCharacterLib);
        } else {
            return ResponseBean.error("保存失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @RequestMapping(value="/admin/character-lib/{id}", method= RequestMethod.DELETE)
    @ApiOperation(value="删除", notes = "删除", httpMethod = "DELETE", response = ResponseBean.class)
    public ResponseBean tdCharacterLibDelete(@ApiParam("对象ID") @PathVariable String id) throws Exception{
        if(iTdCharacterLibService.removeLogicById(id)){
            return ResponseBean.success("success");
        }else {
            return ResponseBean.error("删除失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param tdCharacterLib 实体对象
     * @return
     */
    @RequestMapping(value="/admin/character-lib/{id}",method= RequestMethod.PUT)
    @ApiOperation(value="更新", notes = "更新", httpMethod = "PUT", response = ResponseBean.class)
    public ResponseBean tdCharacterLibUpdate(@ApiParam("对象ID") @PathVariable String id,
                                             @ApiParam("更新内容") @RequestBody TdCharacterLib tdCharacterLib,
                                             HttpServletRequest request) throws Exception{
        SysUser user = getCurrentUser(request);
        tdCharacterLib.setLibId(id);

        if (iTdCharacterLibService.updateWithList(user, tdCharacterLib)){
            return ResponseBean.success(iTdCharacterLibService.getById(id));
        } else {
            return ResponseBean.error("修改失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/admin/character-lib/{id}",method= RequestMethod.GET)
    @ApiOperation(value="详情", notes = "详情", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean tdCharacterLibGet(@ApiParam("对象ID") @PathVariable String id,
                                          HttpServletRequest request) throws Exception{

        TdCharacterLib tdCharacterLib = iTdCharacterLibService.getById(id);
        if (null == tdCharacterLib || Constants.STATUS_DELETED == tdCharacterLib.getStatus()) {
            ResponseBean.error("未找到对应特征库", ResponseBean.ERROR_UNAVAILABLE);
        }

        SysUser user = getCurrentUser(request);
        int rows = iTdCharacterLibService.getCountOfMapUser(user.getUserId(), id);
        if (rows < 1) {
            ResponseBean.error("未找到对应特征库", ResponseBean.ERROR_UNAVAILABLE);
        }

        // 查询明细
        List<TdCharacterWord> wordList = iTdCharacterWordService.getListByLidId(id);
        tdCharacterLib.setWordList(wordList);

        return ResponseBean.success(tdCharacterLib);
    }
}
