package com.yunzhi.questions.service.impl;

import com.yunzhi.questions.common.Constants;
import com.yunzhi.questions.common.StringUtils;
import com.yunzhi.questions.entity.SysUser;
import com.yunzhi.questions.entity.TaCharacterResult;
import com.yunzhi.questions.entity.TdCharacterLib;
import com.yunzhi.questions.entity.TdCharacterWord;
import com.yunzhi.questions.mapper.TaCharacterResultMapper;
import com.yunzhi.questions.mapper.TdCharacterLibMapper;
import com.yunzhi.questions.mapper.TdCharacterWordMapper;
import com.yunzhi.questions.service.ITaCharacterResultService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.time.LocalDateTime;

/**
 * <p>
 * 游戏特征实例 服务实现类
 * </p>
 *
 * @author yansen
 * @since 2021-12-15
 */
@Service
public class TaCharacterResultServiceImpl extends BaseServiceImpl<TaCharacterResultMapper, TaCharacterResult> implements ITaCharacterResultService {

    @Autowired
    TdCharacterLibMapper tdCharacterLibMapper;

    @Autowired
    TdCharacterWordMapper tdCharacterWordMapper;

    @Transactional(rollbackFor = Exception.class)
    @Override
    public boolean saveWithWords(SysUser user, TaCharacterResult taCharacterResult) throws Exception {
        taCharacterResult.setResultId(null);
        taCharacterResult.setCreateDate(LocalDateTime.now());
        if (null == taCharacterResult.getStatus()) {
            taCharacterResult.setStatus(Constants.STATUS_NORMAL);
        }

        // 先保存
        if (!save(taCharacterResult)) return false;

        // 再保存明细
        if (null == taCharacterResult.getWordList()) return true;
        insertWordList(taCharacterResult);

        // 再插入映射表
        int rows;
        for (TdCharacterWord word : taCharacterResult.getWordList()) {
            rows = baseMapper.insertWord(taCharacterResult.getResultId(), word.getWordId());
            if (rows < 1) {
                throw new Exception("映射词库明细失败, 请重试");
            }
        }

        return true;
    }

    @Override
    public boolean updateWithWords(TaCharacterResult taCharacterResult) throws Exception {
        // 先更新
        if (!updateById(taCharacterResult)) return false;

        // 删除所有映射
        baseMapper.removeWords(taCharacterResult.getResultId());

        // 再保存明细
        if (null == taCharacterResult.getWordList()) return true;
        insertWordList(taCharacterResult);

        // 再插入映射表
        int rows;
        for (TdCharacterWord word : taCharacterResult.getWordList()) {
            rows = baseMapper.insertWord(taCharacterResult.getResultId(), word.getWordId());
            if (rows < 1) {
                throw new Exception("映射词库明细失败, 请重试");
            }
        }

        return true;
    }

    private void insertWordList(TaCharacterResult taCharacterResult) throws Exception {
        int rows, count;

        String libId = taCharacterResult.getLibId();
        for (TdCharacterWord word: taCharacterResult.getWordList()) {
            count = tdCharacterWordMapper.countBy(libId, word.getWord());
            if (count > 0) continue;

            word.setWordId(null);
            word.setLibId(taCharacterResult.getLibId());
            word.setCreateDate(LocalDateTime.now());

            rows = tdCharacterWordMapper.insert(word);
            if (rows < 1) {
                throw new Exception("插入词库明细失败, 请重试");
            }
        }
    }
}
