package com.yunzhi.questions.service.impl;

import com.yunzhi.questions.common.Constants;
import com.yunzhi.questions.common.StringUtils;
import com.yunzhi.questions.entity.TaGame;
import com.yunzhi.questions.entity.TaGamePersonAnswer;
import com.yunzhi.questions.entity.TaGamePersonResult;
import com.yunzhi.questions.entity.TaQuestion;
import com.yunzhi.questions.mapper.*;
import com.yunzhi.questions.service.ITaGamePersonResultService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.yunzhi.questions.vo.CharacterInstWithWords;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.time.LocalDateTime;
import java.util.Arrays;
import java.util.List;

/**
 * <p>
 * 问答游戏总结 服务实现类
 * </p>
 *
 * @author yansen
 * @since 2021-12-15
 */
@Service
public class TaGamePersonResultServiceImpl extends ServiceImpl<TaGamePersonResultMapper, TaGamePersonResult> implements ITaGamePersonResultService {

    @Autowired
    TaGameMapper taGameMapper;

    @Autowired
    TaQuestionMapper taQuestionMapper;

    @Autowired
    TaCharacterResultMapper taCharacterResultMapper;

    @Autowired
    TaGamePersonAnswerMapper taGamePersonAnswerMapper;

    @Transactional(rollbackFor = Exception.class)
    @Override
    public boolean makeAnswer(TaGamePersonResult taGamePersonResult) throws Exception {
        String gameId = taGamePersonResult.getGameId();
        String personId = taGamePersonResult.getPersonId();

        // 问答
        TaGame taGame = taGameMapper.selectById(gameId);

        // 获取标准答案
//        List<TaQuestion> standAnswerList = taQuestionMapper.getByGame(taGamePersonResult.getGameId());

        // 问答列表入库
        for (TaGamePersonAnswer answer : taGamePersonResult.getAnswerList()) {
            answer.setGameId(gameId);
            answer.setPersonId(personId);
            answer.setCreateDate(LocalDateTime.now());

            taGamePersonAnswerMapper.insert(answer);
        }

        // 特征匹配类游戏
        if (Constants.GAME_OF_CHARACTER_MATCHED.equals(taGame.getResultMode())) {
            savePersonCharacterResult(taGamePersonResult);
        }

        return true;
    }

    private void savePersonCharacterResult(TaGamePersonResult taGamePersonResult) throws Exception {
        String gameId = taGamePersonResult.getGameId();
        String personId = taGamePersonResult.getPersonId();

        List<CharacterInstWithWords> characterInstList = taCharacterResultMapper.getInstListBy(gameId);
        if (null == characterInstList) {
            throw new Exception("查询标准特征库失败");
        }

        // 入库之后就可以查询当前人员回答特征词了
        List<String> personAnswerWordIdList = baseMapper.getPersonAnswerWordIdList(gameId, personId);

        for(CharacterInstWithWords item : characterInstList) {
            String[] wordsList = StringUtils.ifNull(item.getWordIdStr(), "").split(",");
            if (0 == wordsList.length) {
                item.setScore(0f);
                continue;
            }

            int cnt = Arrays.stream(wordsList).mapToInt(x -> personAnswerWordIdList.contains(x) ? 1 : 0).sum();

            item.setScore((float) (cnt / wordsList.length));
        }

        // 最高得分的
        CharacterInstWithWords maxSocre = null;
        for(CharacterInstWithWords item : characterInstList) {
            if (maxSocre == null) {
                maxSocre = item;
            } else {
                if (maxSocre.getScore() < item.getScore()) {
                    maxSocre = item;
                }
            }
        }

        taGamePersonResult.setResultId(maxSocre.getResultId());
        taGamePersonResult.setStatus(Constants.STATUS_NORMAL);

        baseMapper.insert(taGamePersonResult);
    }
}
