package com.yunzhi.questions.service.impl;

import com.yunzhi.questions.common.Constants;
import com.yunzhi.questions.common.StringUtils;
import com.yunzhi.questions.entity.TaAnswer;
import com.yunzhi.questions.entity.TaQuestion;
import com.yunzhi.questions.mapper.TaAnswerMapper;
import com.yunzhi.questions.mapper.TaQuestionMapper;
import com.yunzhi.questions.service.ITaQuestionService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.yunzhi.questions.vo.QuestionVO;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.time.LocalDateTime;
import java.util.List;

/**
 * <p>
 * 题库 服务实现类
 * </p>
 *
 * @author yansen
 * @since 2021-12-10
 */
@Service
public class TaQuestionServiceImpl extends BaseServiceImpl<TaQuestionMapper, TaQuestion> implements ITaQuestionService {

    @Autowired
    TaAnswerMapper taAnswerMapper;

    @Transactional(rollbackFor = Exception.class)
    @Override
    public boolean saveByVO(QuestionVO questionVO) throws Exception {

        TaQuestion taQuestion = new TaQuestion();
        BeanUtils.copyProperties(questionVO, taQuestion);
        taQuestion.setQuestionId(null);
        taQuestion.setCreateDate(LocalDateTime.now());
        if (null == taQuestion.getStatus()) {
            taQuestion.setStatus(Constants.STATUS_READY);
        }

        boolean success = save(taQuestion);
        if (!success) return success;

        editAnswerList(taQuestion, questionVO.getAnswerList());

        return true;
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public boolean editBy(QuestionVO questionVO) throws Exception {
        TaQuestion taQuestion = new TaQuestion();
        BeanUtils.copyProperties(questionVO, taQuestion);

        boolean success = updateById(taQuestion);
        if (!success) return success;

        editAnswerList(taQuestion, questionVO.getAnswerList());

        return true;
    }

    @Override
    public int countByGameId(String gameId) {
        return baseMapper.countByGameId(gameId);
    }

    private void editAnswerList(TaQuestion taQuestion, List<TaAnswer> answerList) throws Exception {

        String questionId = taQuestion.getQuestionId();

        // 先删除所有选项
        taAnswerMapper.deleteByQuestionID(questionId);

        //
        for (TaAnswer taAnswer : answerList) {
            taAnswer.setAnswerId(null);
            taAnswer.setQuestionId(questionId);

            if (StringUtils.isEmpty(taAnswer.getOption())) {
                throw new Exception("答案选项不能为空");
            }
            if (StringUtils.isEmpty(taAnswer.getContent())) {
                throw new Exception("答案内容不能为空");
            }

            taAnswer.setStatus(Constants.STATUS_NORMAL);

            taAnswerMapper.insert(taAnswer);
        }
    }
}
