package com.yunzhi.questions.service.impl;

import com.yunzhi.questions.common.Constants;
import com.yunzhi.questions.common.StringUtils;
import com.yunzhi.questions.entity.SysUser;
import com.yunzhi.questions.entity.TdCharacterLib;
import com.yunzhi.questions.entity.TdCharacterWord;
import com.yunzhi.questions.mapper.TdCharacterLibMapper;
import com.yunzhi.questions.mapper.TdCharacterWordMapper;
import com.yunzhi.questions.service.ITdCharacterLibService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.time.LocalDateTime;
import java.util.List;
import java.util.stream.Collectors;

/**
 * <p>
 * 特征库 服务实现类
 * </p>
 *
 * @author yansen
 * @since 2021-12-14
 */
@Service
public class TdCharacterLibServiceImpl extends BaseServiceImpl<TdCharacterLibMapper, TdCharacterLib> implements ITdCharacterLibService {

    @Autowired
    TdCharacterWordMapper tdCharacterWordMapper;

    @Transactional(rollbackFor = Exception.class)
    @Override
    public boolean saveWithList(SysUser user, TdCharacterLib tdCharacterLib) throws Exception {
        LocalDateTime now = LocalDateTime.now();
        tdCharacterLib.setLibId(null);
        tdCharacterLib.setCreateDate(now);
        if (null == tdCharacterLib.getStatus()) {
            tdCharacterLib.setStatus(Constants.STATUS_NORMAL);
        }

        // 先保存主记录
        if (!save(tdCharacterLib)) return false;

        // 再保存人员映射
        int rows = baseMapper.saveUserMapLib(user.getUserId(), tdCharacterLib.getLibId());
        if (rows < 1) {
            throw new Exception("映射人员特征库失败, 请重试");
        }

        // 再保存明细
        if (null == tdCharacterLib.getWordList()) return true;
        insertWordList(tdCharacterLib);

        return true;
    }

    private void insertWordList(TdCharacterLib tdCharacterLib) throws Exception {
        int rows;
        for (TdCharacterWord word: tdCharacterLib.getWordList()) {
            if (!StringUtils.isEmpty(word.getWordId())) continue;

            word.setLibId(tdCharacterLib.getLibId());
            word.setCreateDate(LocalDateTime.now());

            rows = tdCharacterWordMapper.insert(word);
            if (rows < 1) {
                throw new Exception("插入词库明细失败, 请重试");
            }
        }
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public boolean updateWithList(SysUser user, TdCharacterLib tdCharacterLib) throws Exception {
        // 先校验关联人员
        int rows = getCountOfMapUser(user.getUserId(), tdCharacterLib.getLibId());
        if (rows < 1) {
            throw new Exception("未找到当前ID对应特征库");
        }

        // 更新主记录
        if (!updateById(tdCharacterLib)) return false;

        // 删除需要删除的部分
        List<String> wordIdList = tdCharacterLib.getWordList().stream()
                .map(TdCharacterWord::getWordId)
                .filter(x -> !StringUtils.isEmpty(x))
                .collect(Collectors.toList());
        if (wordIdList.size() > 0) {
            tdCharacterWordMapper.deleteByLibId(tdCharacterLib.getLibId(), wordIdList);
        }

        // 再插入明细
        if (null == tdCharacterLib.getWordList()) return true;
        insertWordList(tdCharacterLib);

        return true;
    }

    @Override
    public int getCountOfMapUser(String userId, String libId) {
        return baseMapper.getCountOfMapUser(userId, libId);
    }
}
